Shader "ImageEffect/DarknessEffect"
{
    Properties
    {
        _MainTex ("Texture", 2D) = "white" {}
        _MaskTex ("Texture", 2D) = "white" {}
        _BackgroundColor("BackGround Color", Color) = (.25, .5, .5, 1)
        _MaskColor("Mask Color", Color) = (1, 1, 1, 1)
        _Apply("Light", Range(0.0, 1.0)) = 1.0
        _KeepColors("Show Mask Color", Range(0.0, 1.0)) = 1
    }
    SubShader
    {
        // No culling or depth
        Cull Off ZWrite Off ZTest Always

        Pass
        {
            CGPROGRAM
            #pragma vertex vert
            #pragma fragment frag

            #include "UnityCG.cginc"

            struct appdata
            {
                float4 vertex : POSITION;
                float2 uv : TEXCOORD0;
            };

            struct v2f
            {
                float2 uv : TEXCOORD0;
                float4 vertex : SV_POSITION;
            };

            v2f vert (appdata v)
            {
                v2f o;
                o.vertex = UnityObjectToClipPos(v.vertex);
                o.uv = v.uv;
                return o;
            }

            sampler2D _MainTex;
            sampler2D _MaskTex;
            float4 _BackgroundColor;
            float4 _MaskColor;
            float _Apply;
            float _KeepColors;

            fixed4 frag (v2f i) : SV_Target
            {
                fixed4 lightCol = tex2D(_MainTex, i.uv);
                fixed4 mask = tex2D(_MaskTex, i.uv);
                             
                float4 darkCol = mask * lerp(_MaskColor, lightCol, _KeepColors) + ((1 - mask) * _BackgroundColor);

                return lerp(darkCol, lightCol, _Apply);

            }
            ENDCG
        }
    }
}
